EXPORTS
	??1CCameraHistogram@CCamera@@UAE@XZ @ 1 NONAME ; CCamera::CCameraHistogram::~CCameraHistogram(void)
	?DestroyHistogramL@CCameraHistogram@CCamera@@QAEXI@Z @ 2 NONAME ; void CCamera::CCameraHistogram::DestroyHistogramL(unsigned int)
	?GetActiveHistogramsL@CCameraHistogram@CCamera@@QAEXAAV?$RArray@I@@@Z @ 3 NONAME ; void CCamera::CCameraHistogram::GetActiveHistogramsL(class RArray<unsigned int> &)
	?GetDSAHistogramPropertiesL@CCameraHistogram@CCamera@@QAEXIAAVTPoint@@AAVTSize@@AAVTRgb@@@Z @ 4 NONAME ; void CCamera::CCameraHistogram::GetDSAHistogramPropertiesL(unsigned int, class TPoint &, class TSize &, class TRgb &)
	?HistogramDataL@CCameraHistogram@CCamera@@QAEAAVMHistogramBuffer@@I@Z @ 5 NONAME ; class MHistogramBuffer & CCamera::CCameraHistogram::HistogramDataL(unsigned int)
	?HistogramDataL@CCameraHistogram@CCamera@@QAEAAVMHistogramBuffer@@XZ @ 6 NONAME ; class MHistogramBuffer & CCamera::CCameraHistogram::HistogramDataL(void)
	?NewL@CCameraHistogram@CCamera@@SAPAV12@AAV2@@Z @ 7 NONAME ; class CCamera::CCameraHistogram * CCamera::CCameraHistogram::NewL(class CCamera &)
	?PrepareDSAHistogramL@CCameraHistogram@CCamera@@QAEIW4THistogramType@12@ABVTPoint@@ABVTSize@@ABVTRgb@@@Z @ 8 NONAME ; unsigned int CCamera::CCameraHistogram::PrepareDSAHistogramL(enum CCamera::CCameraHistogram::THistogramType, class TPoint const &, class TSize const &, class TRgb const &)
	?PrepareHistogramL@CCameraHistogram@CCamera@@QAEIW4THistogramType@12@@Z @ 9 NONAME ; unsigned int CCamera::CCameraHistogram::PrepareHistogramL(enum CCamera::CCameraHistogram::THistogramType)
	?StartHistogramL@CCameraHistogram@CCamera@@QAEXI@Z @ 10 NONAME ; void CCamera::CCameraHistogram::StartHistogramL(unsigned int)
	?StopHistogramL@CCameraHistogram@CCamera@@QAEXI@Z @ 11 NONAME ; void CCamera::CCameraHistogram::StopHistogramL(unsigned int)
	?SupportedHistograms@CCameraHistogram@CCamera@@QAEKXZ @ 12 NONAME ; unsigned long CCamera::CCameraHistogram::SupportedHistograms(void)
	?UpdateDSAHistogramPropertiesL@CCameraHistogram@CCamera@@QAEXIABVTPoint@@ABVTSize@@ABVTRgb@@@Z @ 13 NONAME ; void CCamera::CCameraHistogram::UpdateDSAHistogramPropertiesL(unsigned int, class TPoint const &, class TSize const &, class TRgb const &)
	??0TDirectHistogramParameters@CCameraV2Histogram@CCamera@@QAE@XZ @ 14 NONAME ; CCamera::CCameraV2Histogram::TDirectHistogramParameters::TDirectHistogramParameters(void)
	??1CCameraV2Histogram@CCamera@@UAE@XZ @ 15 NONAME ; CCamera::CCameraV2Histogram::~CCameraV2Histogram(void)
	?CreateL@CCameraV2Histogram@CCamera@@CAPAV12@AAV2@AAVMImplementationFactory@@@Z @ 16 NONAME ; class CCamera::CCameraV2Histogram * CCamera::CCameraV2Histogram::CreateL(class CCamera &, class MImplementationFactory &)
	?GetDirectHistogramPropertiesL@CCameraV2Histogram@CCamera@@QBEXAAVTDirectHistogramParameters@12@@Z @ 17 NONAME ; void CCamera::CCameraV2Histogram::GetDirectHistogramPropertiesL(class CCamera::CCameraV2Histogram::TDirectHistogramParameters &) const
	?GetDirectHistogramSupportInfoL@CCameraV2Histogram@CCamera@@QBEXAAH@Z @ 18 NONAME ; void CCamera::CCameraV2Histogram::GetDirectHistogramSupportInfoL(int &) const
	?GetHistogramStateL@CCameraV2Histogram@CCamera@@QBEXAAH@Z @ 19 NONAME ; void CCamera::CCameraV2Histogram::GetHistogramStateL(int &) const
	?GetSupportedHistogramsL@CCameraV2Histogram@CCamera@@QBEXAAI@Z @ 20 NONAME ; void CCamera::CCameraV2Histogram::GetSupportedHistogramsL(unsigned int &) const
	?PrepareClientHistogramL@CCameraV2Histogram@CCamera@@QAEXW4THistogramType@12@@Z @ 21 NONAME ; void CCamera::CCameraV2Histogram::PrepareClientHistogramL(enum CCamera::CCameraV2Histogram::THistogramType)
	?PrepareDirectHistogramL@CCameraV2Histogram@CCamera@@QAEXABVTDirectHistogramParameters@12@@Z @ 22 NONAME ; void CCamera::CCameraV2Histogram::PrepareDirectHistogramL(class CCamera::CCameraV2Histogram::TDirectHistogramParameters const &)
	?Size@TDirectHistogramParameters@CCameraV2Histogram@CCamera@@QBEIXZ @ 23 NONAME ; unsigned int CCamera::CCameraV2Histogram::TDirectHistogramParameters::Size(void) const
	?StartHistogram@CCameraV2Histogram@CCamera@@QAEXXZ @ 24 NONAME ; void CCamera::CCameraV2Histogram::StartHistogram(void)
	?StopHistogram@CCameraV2Histogram@CCamera@@QAEXXZ @ 25 NONAME ; void CCamera::CCameraV2Histogram::StopHistogram(void)
	?UpdateDirectHistogramPropertiesL@CCameraV2Histogram@CCamera@@QAEXABVTDirectHistogramParameters@12@@Z @ 26 NONAME ; void CCamera::CCameraV2Histogram::UpdateDirectHistogramPropertiesL(class CCamera::CCameraV2Histogram::TDirectHistogramParameters const &)
	?Version@TDirectHistogramParameters@CCameraV2Histogram@CCamera@@QBEIXZ @ 27 NONAME ; unsigned int CCamera::CCameraV2Histogram::TDirectHistogramParameters::Version(void) const

